# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ChatMessageKind(str, Enum):
    """
    ChatMessageKind
    """

    """
    allowed enum values
    """
    TEXT = 'text'
    IMAGE = 'image'
    FILE = 'file'
    TRANSCRIPT_SEARCH = 'transcript_search'
    TRANSCRIPT_RESULT = 'transcript_result'
    AUDIO_PLAYBACK = 'audio_playback'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ChatMessageKind from a JSON string"""
        return cls(json.loads(json_str))


