# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.artifact_data_create import ArtifactDataCreate
from keplar_api.models.artifact_metadata import ArtifactMetadata
from typing import Optional, Set
from typing_extensions import Self

class CreateArtifactRequest(BaseModel):
    """
    CreateArtifactRequest
    """ # noqa: E501
    kind: Optional[StrictStr] = None
    version_group_id: Optional[StrictStr] = Field(default=None, alias="versionGroupId")
    query: Optional[StrictStr] = None
    previous_artifact_id: Optional[StrictStr] = Field(default=None, alias="previousArtifactId")
    data: Optional[ArtifactDataCreate] = None
    metadata: Optional[ArtifactMetadata] = None
    title: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["kind", "versionGroupId", "query", "previousArtifactId", "data", "metadata", "title"]

    @field_validator('kind')
    def kind_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['thematic_analysis', 'report', 'search_result', 'presentation']):
            raise ValueError("must be one of enum values ('thematic_analysis', 'report', 'search_result', 'presentation')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateArtifactRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateArtifactRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "kind": obj.get("kind"),
            "versionGroupId": obj.get("versionGroupId"),
            "query": obj.get("query"),
            "previousArtifactId": obj.get("previousArtifactId"),
            "data": ArtifactDataCreate.from_dict(obj["data"]) if obj.get("data") is not None else None,
            "metadata": ArtifactMetadata.from_dict(obj["metadata"]) if obj.get("metadata") is not None else None,
            "title": obj.get("title")
        })
        return _obj


